Documentation
¶
Overview ¶
Package innoextract reads files embedded in Inno Setup installers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrInvalidFormat = fault.ErrInvalidFormat ErrUnsupportedVersion = fault.ErrUnsupportedVersion ErrPasswordRequired = fault.ErrPasswordRequired ErrIncorrectPassword = fault.ErrIncorrectPassword ErrUnsupportedEncryption = fault.ErrUnsupportedEncryption ErrUnsupportedCompression = fault.ErrUnsupportedCompression ErrMissingSlice = fault.ErrMissingSlice ErrChecksumMismatch = fault.ErrChecksumMismatch ErrCorrupt = fault.ErrCorrupt ErrLimitExceeded = fault.ErrLimitExceeded )
Functions ¶
This section is empty.
Types ¶
type Archive ¶
type Archive struct {
// contains filtered or unexported fields
}
Archive is a parsed Inno Setup installer. Its methods do not write to disk.
type ChecksumType ¶
type ChecksumType string
ChecksumType identifies an installer-provided checksum.
const ( ChecksumNone ChecksumType = "" ChecksumAdler32 ChecksumType = "adler32" ChecksumCRC32 ChecksumType = "crc32" ChecksumMD5 ChecksumType = "md5" ChecksumSHA1 ChecksumType = "sha1" ChecksumSHA256 ChecksumType = "sha256" )
type EntryError ¶
func (EntryError) Error ¶
func (e EntryError) Error() string
func (EntryError) Unwrap ¶
func (e EntryError) Unwrap() error
type ExtractError ¶
type ExtractError struct {
Failures []EntryError
}
func (*ExtractError) Error ¶
func (e *ExtractError) Error() string
func (*ExtractError) Unwrap ¶
func (e *ExtractError) Unwrap() []error
type Option ¶
type Option func(*options) error
func WithCodepage ¶
func WithMemoryLimit ¶
func WithPassword ¶
func WithSliceProvider ¶
func WithSliceProvider(provider SliceProvider) Option
Directories
¶
| Path | Synopsis |
|---|---|
|
internal
|
|
|
crypto
Package crypto contains the small set of cryptographic primitives used by the Inno Setup data stream.
|
Package crypto contains the small set of cryptographic primitives used by the Inno Setup data stream. |
|
gog
Package gog contains the format-only parts of GOG installer handling.
|
Package gog contains the format-only parts of GOG installer handling. |
|
loader
Package loader locates the Inno Setup payloads embedded in an executable.
|
Package loader locates the Inno Setup payloads embedded in an executable. |
|
pathutil
Package pathutil contains the path rules used when turning an Inno Setup destination into a path that is safe to hand to a caller.
|
Package pathutil contains the path rules used when turning an Inno Setup destination into a path that is safe to hand to a caller. |
|
setup
Package setup decodes the metadata streams used by modern Inno Setup files.
|
Package setup decodes the metadata streams used by modern Inno Setup files. |
|
stream
Package stream decodes the compressed data portions described by the parser's internal format model.
|
Package stream decodes the compressed data portions described by the parser's internal format model. |
Click to show internal directories.
Click to hide internal directories.